import React from 'react';
import { StyleSheet, Text, View, TouchableOpacity, AsyncStorage, Alert, StatusBar, ImageBackground, Image } from 'react-native';


const SEND_DATA_TIMER = 60000;

const INFO_TIMER = 1000;



class App extends React.PureComponent {

    constructor(props) {
        super(props);
        this.state = {
            mode: 'rating',
            stats: {},
            statsLoading: false,
            buffer: []
        };

        this.sendData = this.sendData.bind(this);
        this.onPress = this.onPress.bind(this);
    }

    componentDidMount() {
        this.timer = setInterval(this.sendData, SEND_DATA_TIMER);
    }

    componentWillUnmount() {
        if (this.timer) {
            clearInterval(this.timer);
        }
    }


    async sendData() {
        let { buffer } = this.state;
        let body = [];

        //prepare body
        while (buffer.length) {
            body.push(buffer.shift());
        }

        if (!body.length) {
            // do nothing
            return;
        }

        let response;
        try {
            
            response = await fetch('https://radegast.janhrabal.com/api/ratings', {
                method: "POST",
                body: JSON.stringify(body),
                headers: {
                    'Content-Type': 'application/json',
                }
            });

        } catch (error) {
            //console.error(error);
            // return to buffer
            while (body.length) {
                buffer.push(body.shift());
            }

            response && console.warn("status " + response.status);
            console.warn("sendData - error", this.state.buffer);
        }
    }


    onPress(r) {
        return async () => {
            let { buffer } = this.state;
            let key = new Date().getTime();
            let rating = { rating: r, key };

            try {
                this.setState({ mode: "info" });
                await AsyncStorage.setItem(JSON.stringify(key), JSON.stringify(rating));

                //add to buffer
                buffer.push(rating);

                setTimeout(() => this.setState({ mode: "rating" }), INFO_TIMER);

            } catch (e) {
                console.error(e);
                this.setState({ mode: "rating" });
            }  
        }
    }


    renderResults() {
        return <View></View>
    }


    renderInfo() {
        return <View style={styles.center}><Text>Děkujeme za hodnocení</Text></View>
    }


    renderRating() {
        const buttons = [];
        for (let i = 1; i <= 10; i++) {
            buttons.push(<TouchableOpacity key={ i } onPress={ this.onPress(i) }>
                <Text style={styles.rating}>{ i }</Text>
            </TouchableOpacity>
            );
        }

        return (
            <View style={styles.ratingsContainer}>
                { buttons }
            </View>
        );
    }


    render() {
        let { mode } = this.state;

        let content = null;

        switch (mode) {
            case 'results':
                content = this.renderResults();
                break;
            case 'info':
            default:
                content = this.renderRating();

        }

        return (
            <View style={styles.container}>
                <StatusBar hidden />
                <Image source={ require('./assets/bg.jpg') } style={{width: '100%', height: '100%', position: 'absolute'}} imageStyle={{ resizeMode: 'stretch' }}/>
                { content }
            </View>
        );
    }


}


export default App;


const styles = StyleSheet.create({
    center: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
    },

    ratingsContainer: {
        position: 'absolute',
        left: 0,
        top: '35%',
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-around',
        color: '#FFFFFF',
        paddingLeft: '5%',
        paddingRight: '5%'
    },

    rating: {
        backgroundColor: '#FFFFFF',
        fontSize: 20,
        borderRadius: 14,
        width: 28,
        height: 28,
        textAlign: 'center'
    },

    container: {
        flex: 1,
        backgroundColor: '#000000'
    },
});
